@@ -1420,7 +1420,7 @@ static PurplePluginInfo info = {
     PURPLE_PRIORITY_DEFAULT,    /**< priority	*/
     PLUGIN_ID,                  /**< id     */
     "Pidgin-Twitter",           /**< name	*/
-    "0.9.1",                    /**< version	*/
+    "0.9.2",                    /**< version	*/
     "provides useful features for twitter", /**  summary	*/
     "provides useful features for twitter", /**  desc	*/
     "Yoshiki Yazawa, mikanbako, \nKonosuke Watanabe, IWATA Ray, \nmojin, umq, \nthe pidging-twitter team",     /**< author	*/
@@ -1450,7 +1450,7 @@ init_plugin(PurplePlugin *plugin)
     purple_prefs_add_bool(OPT_TRANSLATE_RECIPIENT, TRUE);
     purple_prefs_add_bool(OPT_TRANSLATE_SENDER, TRUE);
     purple_prefs_add_bool(OPT_TRANSLATE_CHANNEL, TRUE);
-    purple_prefs_add_bool(OPT_ESCAPE_PSEUDO, TRUE);
+    purple_prefs_add_bool(OPT_ESCAPE_PSEUDO, FALSE);
     purple_prefs_add_bool(OPT_STRIP_EXCESS_LF, TRUE);
 
     purple_prefs_add_bool(OPT_PLAYSOUND_RECIPIENT, TRUE);
